        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 17 <strong>control</strong><br>0,1,3,10,13,14,16,17,30,34,35,37,41,42,43,44,47';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 13 <br>2,5,6,8,9,12,15,20,25,29,45,48,49';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 10 <br>11,18,24,26,31,33,36,39,40,50';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 7 <br>19,21,22,23,28,32,38';}
       if(rr==6 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>7</strong> miembros: 4 <br>4,7,27,46';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 17 <strong>control</strong><br>0,1,3,10,13,14,16,17,30,34,35,37,41,42,43,44,47';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 13 <br>2,5,6,8,9,12,15,20,25,29,45,48,49';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 10 <br>11,18,24,26,31,33,36,39,40,50';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 7 <br>19,21,22,23,28,32,38';}
       if(rr==29 && cc==5){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>7</strong> miembros: 4 <br>4,7,27,46';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 17 <strong>control</strong><br>0,1,3,10,13,14,16,17,30,34,35,37,41,42,43,44,47';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 13 <br>2,5,6,8,9,12,15,20,25,29,45,48,49';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 10 <br>11,18,24,26,31,33,36,39,40,50';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 7 <br>19,21,22,23,28,32,38';}
       if(rr==30 && cc==5){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>7</strong> miembros: 4 <br>4,7,27,46';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 17 <strong>control</strong><br>0,1,3,10,13,14,16,17,30,34,35,37,41,42,43,44,47';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 13 <br>2,5,6,8,9,12,15,20,25,29,45,48,49';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 10 <br>11,18,24,26,31,33,36,39,40,50';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 7 <br>19,21,22,23,28,32,38';}
       if(rr==31 && cc==5){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>7</strong> miembros: 4 <br>4,7,27,46';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 17 <strong>control</strong><br>0,1,3,10,13,14,16,17,30,34,35,37,41,42,43,44,47';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 13 <br>2,5,6,8,9,12,15,20,25,29,45,48,49';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 10 <br>11,18,24,26,31,33,36,39,40,50';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 7 <br>19,21,22,23,28,32,38';}
       if(rr==32 && cc==5){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>7</strong> miembros: 4 <br>4,7,27,46';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 17 <strong>control</strong><br>0,1,3,10,13,14,16,17,30,34,35,37,41,42,43,44,47';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>20</strong> miembros: 13 <br>2,5,6,8,9,12,15,20,25,29,45,48,49';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 10 <br>11,18,24,26,31,33,36,39,40,50';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>28</strong> miembros: 7 <br>19,21,22,23,28,32,38';}
       if(rr==33 && cc==5){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260606 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>7</strong> miembros: 4 <br>4,7,27,46';}
}
